@@ -124,7 +124,7 @@
 //! The full dependency graph, where dashed lines indicate optional
 //! dependencies, is shown below:
 //!
-//! <img src="https://raw.githubusercontent.com/mgeisler/textwrap/master/images/textwrap-0.14.0.svg">
+//! <img src="https://raw.githubusercontent.com/mgeisler/textwrap/master/images/textwrap-0.14.1.svg">
 //!
 //! ## Default Features
 //!
@@ -168,7 +168,8 @@
 //!   [`Options::with_termwidth`] constructor for details.
 //!
 //! * `hyphenation`: enables language-sensitive hyphenation via the
-//!   [hyphenation] crate. See the [`word_splitters::WordSplitter`] trait for details.
+//!   [hyphenation] crate. See the [`word_splitters::WordSplitter`]
+//!   trait for details.
 //!
 //! [unicode-linebreak]: https://docs.rs/unicode-linebreak/
 //! [unicode-width]: https://docs.rs/unicode-width/
@@ -177,7 +178,7 @@
 //! [terminal_size]: https://docs.rs/terminal_size/
 //! [hyphenation]: https://docs.rs/hyphenation/
 
-#![doc(html_root_url = "https://docs.rs/textwrap/0.14.0")]
+#![doc(html_root_url = "https://docs.rs/textwrap/0.14.1")]
 #![forbid(unsafe_code)] // See https://github.com/mgeisler/textwrap/issues/210
 #![deny(missing_docs)]
 #![deny(missing_debug_implementations)]
@@ -316,9 +317,9 @@ impl<'a>
     ///     #[cfg(not(feature = "unicode-linebreak"))]
     ///     word_separator: textwrap::word_separators::AsciiSpace,
     ///     #[cfg(feature = "smawk")]
-    ///     wrap_algorithm: textwrap::wrap_algorithms::OptimalFit,
+    ///     wrap_algorithm: textwrap::wrap_algorithms::OptimalFit::new(),
     ///     #[cfg(not(feature = "smawk"))]
-    ///     wrap_algorithm: textwrap::wrap_algorithms::FirstFit,
+    ///     wrap_algorithm: textwrap::wrap_algorithms::FirstFit::new(),
     ///     word_splitter: textwrap::word_splitters::HyphenSplitter,
     /// }
     /// # ;
@@ -428,9 +429,9 @@ impl<'a, WordSplit> Options<'a, DefaultWrapAlgorithm!(), DefaultWordSeparator!()
     ///     #[cfg(not(feature = "unicode-linebreak"))]
     ///     word_separator: textwrap::word_separators::AsciiSpace,
     ///     #[cfg(feature = "smawk")]
-    ///     wrap_algorithm: textwrap::wrap_algorithms::OptimalFit,
+    ///     wrap_algorithm: textwrap::wrap_algorithms::OptimalFit::new(),
     ///     #[cfg(not(feature = "smawk"))]
-    ///     wrap_algorithm: textwrap::wrap_algorithms::FirstFit,
+    ///     wrap_algorithm: textwrap::wrap_algorithms::FirstFit::new(),
     ///     word_splitter: word_splitter,
     /// }
     /// # ;
@@ -491,7 +492,7 @@ impl<'a, WordSplit> Options<'a, DefaultWrapAlgorithm!(), DefaultWordSeparator!()
             subsequent_indent: "",
             break_words: true,
             word_separator: DefaultWordSeparator!(),
-            wrap_algorithm: DefaultWrapAlgorithm!(),
+            wrap_algorithm: <DefaultWrapAlgorithm!()>::new(),
             word_splitter: word_splitter,
         }
     }
@@ -992,7 +993,7 @@ where
 /// # use textwrap::wrap_algorithms::OptimalFit;
 /// #
 /// # let lines = wrap("To be, or not to be: that is the question",
-/// #                  Options::new(10).wrap_algorithm(OptimalFit));
+/// #                  Options::new(10).wrap_algorithm(OptimalFit::new()));
 /// # assert_eq!(lines.join("\n") + "\n", "\
 /// To be,
 /// or not to
@@ -1850,6 +1851,12 @@ mod tests {
         );
     }
 
+    #[test]
+    fn fill_unicode_boundary() {
+        // https://github.com/mgeisler/textwrap/issues/390
+        fill("\u{1b}!Ͽ", 10);
+    }
+
     #[test]
     #[cfg(not(feature = "smawk"))]
     #[cfg(not(feature = "unicode-linebreak"))]
